import { PartialRenderer } from '../renderer';
import { JSXElementAsync } from './jsx';
/**
 * The `PartialRenderer` interface gives us the power to *stream* our
 * asynchronous JSX. Some of our asynchronous JSX nodes will complete earlier
 * than others allowing us to immeadiately send them down while still waiting
 * for the rest. We can do this because `PartialRenderer` allows us to render
 * an element’s opening and closing tags *seperate* from the element’s
 * children.
 *
 * So for example, say we have three promise child nodes that resolve after one
 * second, two seconds, and three seconds respectively. This function creates a
 * function that creates an observable that will emit the opening tag for the
 * root element, then render each child in one second increments, then finally
 * emits the parent element’s closing tag.
 *
 * If the renderer can emit partial values, and a consumer can take and
 * construct them—this function provides exciting performance possibilities.
 * This is one of Vulture’s unique advantages.
 */
export declare function createRenderStream<A, B, C>(renderer: PartialRenderer<A, B, C>): (jsx: boolean | number | string | JSXElementAsync | Promise<boolean | number | string | JSXElementAsync | null | undefined> | Observable<boolean | number | string | JSXElementAsync | null | undefined> | null | undefined) => Observable<A | B | C>;
