import { JSXPrimitive, JSXElement, Attributes, Children } from './jsx';
/**
 * A shortcut function for creating JSX elements for those who may not want to
 * use a JSX transpiler. This function is similar to hyperscript formats,
 * except *much* less complex.
 */
export declare function jsx(elementName: string): JSXElement;
export declare function jsx(elementName: string, attributes: Attributes): JSXElement;
export declare function jsx(elementName: string, children: Children): JSXElement;
export declare function jsx(elementName: string, attributes: Attributes, children: Children): JSXElement;
/**
 * A fast duck-type to check whether any value is a JSX Element. A JSX Element
 * must always be an object with *at least* a string `elementName`, so that’s
 * all we check for.
 */
export declare function isJSXElement(value: any): value is JSXElement;
/**
 * Gets whether a value is a `JSXPrimitive`
 */
export declare function isJSXPrimitive(value: any): value is JSXPrimitive;
/**
 * Transforms a JSX primitive node to a string.
 *
 * If the node is null or undefined, an empty string is returned. If the node
 * is a boolean an empty string is returned (even for `true`!). If the node is
 * a number the node gets cast into a string. If the node is a string, nothing
 * happens.
 *
 * These are fairly intuitive rules, all except for `true` returning an empty
 * string.
 */
export declare function primitiveToString(node: JSXPrimitive): string;
